<?php
// Add main menu item for the plugin
add_action('admin_menu', 'accounting_api_connector_menu');
function accounting_api_connector_menu() {
    add_menu_page('Accounting API Connector', 'حسابداری سبحان API', 'manage_options', 'accounting-api-connector', 'accounting_api_connector_options', 'dashicons-chart-area');
    add_submenu_page('accounting-api-connector', 'تنظیمات انبار', 'تنظیمات انبار', 'manage_options', 'accounting-api-connector-stock', 'accounting_api_connector_stock_options');
    add_submenu_page('accounting-api-connector', 'ایجاد برچسب پستی', 'برچسب پستی', 'manage_options', 'accounting-api-connector-shipping-label', 'accounting_api_shipping_label_options');
    add_submenu_page('accounting-api-connector', 'تنظیمات فاکتور', 'تنظیمات فاکتور', 'manage_options', 'accounting-api-connector-invoice', 'accounting_api_connector_invoice_options');
}

function accounting_api_connector_options() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.'));
    }

    ?>
    <div class="wrap">
        <h1>تنظمات افزونه سبحان</h1>
        <form method="post" action="">
            <?php
            settings_fields('accounting_api_connector_options_group');
            do_settings_sections('accounting-api-connector');
            ?>

            <!-- دکمه تست اتصال -->
            <button type="submit" name="test_connection" class="button-primary">تست اتصال</button>

            <?php
            // بررسی نتیجه اتصال
            if (isset($_POST['test_connection'])) {
                // فراخوانی تابع accounting_api_test_connection
                $connection_status = accounting_api_test_connection();

                if (is_wp_error($connection_status)) {
                    // اگر خطا باشد، نمایش پیغام خطا
                    echo '<div class="notice notice-error is-dismissible">
                        <p>' . $connection_status->get_error_message() . '</p>
                    </div>';
                } else {
                    // اگر موفق باشد
                    echo '<div class="notice notice-success is-dismissible">
                        <p>اتصال به API با موفقیت انجام شد.</p>
                    </div>';
                }
            }
            ?>

            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Register and define the settings
add_action('admin_init', 'accounting_api_connector_settings');
function accounting_api_connector_settings() {
    // حذف register_setting و استفاده از update_option
    add_settings_section(
        'accounting_api_connector_main',
        'تنظیمات اصلی',
        'accounting_api_connector_main_text',
        'accounting-api-connector'
    );

    add_settings_field(
        'accounting_api_username',
        'API Username',
        'accounting_api_username_input',
        'accounting-api-connector',
        'accounting_api_connector_main'
    );

    add_settings_field(
        'accounting_api_password',
        'API Password',
        'accounting_api_password_input',
        'accounting-api-connector',
        'accounting_api_connector_main'
    );
}

function accounting_api_connector_main_text() {
    echo '<p>مشخصات ورود به API را وارد کنید:</p>';
}

function accounting_api_username_input() {
    $username = get_option('accounting_api_username');
    echo "<input id='accounting_api_username' name='accounting_api_username' type='text' value='" . esc_attr($username) . "' />";
}

function accounting_api_password_input() {
    $password = get_option('accounting_api_password');
    echo "<input id='accounting_api_password' name='accounting_api_password' type='password' value='" . esc_attr($password) . "' />";
}

// Process form and save options
if (isset($_POST['accounting_api_username']) && isset($_POST['accounting_api_password'])) {
    $username = sanitize_text_field($_POST['accounting_api_username']);
    $password = sanitize_text_field($_POST['accounting_api_password']);
    
    // Save username and password using update_option
    update_option('accounting_api_username', $username);
    update_option('accounting_api_password', $password);
    
    // Test connection after saving
    if (isset($_POST['test_connection'])) {
         $connection_status = accounting_api_test_connection();

           if (is_wp_error($connection_status)) {
        echo '<div class="notice notice-error is-dismissible"><p>' . $connection_status->get_error_message() . '</p></div>';
    } else {
        echo '<div class="notice notice-success is-dismissible"><p>اتصال به API با موفقیت انجام شد.</p></div>';
    }
    }
}
?>
