<?php
function accounting_api_get_token() {
    // خواندن توکن و تاریخ آخرین به‌روزرسانی
    $token = get_option('accounting_api_token');
    $last_updated = get_option('accounting_api_token_updated_at');
    $username = get_option('accounting_api_username');
    $password = get_option('accounting_api_password');

    // چاپ مقادیر برای عیب‌یابی
    error_log("Token: " . print_r($token, true));  // چاپ توکن
    error_log("Last Updated: " . print_r($last_updated, true));  // چاپ زمان آخرین به‌روزرسانی
    error_log("Username: " . $username);  // چاپ نام کاربری برای بررسی
    error_log("Password: " . $password);  // چاپ رمز عبور برای بررسی

    // اگر توکن قدیمی است یا وجود ندارد
    if (!$token || !$last_updated || time() - $last_updated > 3600) {
        // ارسال درخواست برای دریافت توکن جدید
        $url = 'https://api.app.sobhan.net/login';

        $args = [
            'method'    => 'POST', // استفاده از متد POST
            'timeout'   => 15,
            'body'      => [
                'username' => $username,
                'password' => $password,
            ],
            'headers'   => [
                'Content-Type' => 'application/x-www-form-urlencoded', // نوع محتوا
            ],
        ];

        $response = wp_remote_request($url, $args);

        // بررسی خطاهای درخواست
        if (is_wp_error($response)) {
            error_log('API Login Error: ' . $response->get_error_message());
            return false;
        }

        // پردازش پاسخ
        $body = json_decode(wp_remote_retrieve_body($response), true);

        // چاپ پاسخ برای بررسی
        error_log("API Response: " . print_r($body, true));

        // بررسی وجود توکن در پاسخ
        if (isset($body['token'])) {
    $token = $body['token'];

    // ذخیره توکن
    if (update_option('accounting_api_token', $token)) {
        error_log("Token updated successfully.");
    } else {
        error_log("Failed to update token: " . $token);
    }

    // ذخیره زمان به‌روزرسانی
    if (update_option('accounting_api_token_updated_at', time())) {
        error_log("Token update time saved.");
    } else {
        error_log("Failed to save token update time.");
    }
} else {
    error_log("Token key missing in response: " . print_r($body, true));
    return false;
}

    }

    // چاپ توکن ذخیره‌شده برای بررسی
    $stored_token = get_option('accounting_api_token');
    error_log("Stored Token: " . $stored_token);

    return $token;
}



// فایل اصلی پلاگین (sobhan.php یا هر فایل اصلی پلاگین)

function accounting_api_test_connection() {
    $username = get_option('accounting_api_username');
    $password = get_option('accounting_api_password');

    if (!$username || !$password) {
        return new WP_Error('missing_credentials', 'Username or Password is missing');
    }

    // ساخت URL برای درخواست
    $url = 'https://api.app.sobhan.net/login';

    $args = [
        'method'    => 'POST', // ارسال به صورت POST
        'timeout'   => 15,     // تنظیم زمان تایم اوت
        'body'      => [
            'username' => $username,
            'password' => $password,
        ],
        'headers'   => [
            'Content-Type' => 'application/x-www-form-urlencoded', // ارسال داده‌ها در URL
        ],
    ];

    // ارسال درخواست POST به API
    $response = wp_remote_request($url, $args);

    // بررسی خطاهای درخواست
    if (is_wp_error($response)) {
        $error_message = $response->get_error_message();
        error_log('API Request Error: ' . $error_message); // ذخیره پیغام خطا
        return new WP_Error('api_request_failed', 'API Request failed');
    }

    // بررسی وضعیت HTTP
    $status_code = wp_remote_retrieve_response_code($response);
    if ($status_code !== 200) {
        $body = wp_remote_retrieve_body($response);
        error_log('API Response Error: ' . $body); // ذخیره پاسخ دریافتی از API
        return new WP_Error('invalid_status_code', 'Invalid response status');
    }

    // پردازش پاسخ JSON
    $body = json_decode(wp_remote_retrieve_body($response), true);

    // بررسی وجود توکن در پاسخ
    if (isset($body['token'])) {
        return true; // اتصال موفق
    }

    // در صورتی که توکن وجود نداشته باشد، جزئیات بیشتر از پاسخ را چاپ کنیم
    error_log('Invalid API response: ' . print_r($body, true));
    return new WP_Error('invalid_response', 'Invalid API response');
}


function accounting_api_connector_request($endpoint, $method = 'GET', $body = null) {
    $token = accounting_api_get_token();
    if (!$token) {
        return new WP_Error('api_error', 'عدم موفقیت در دریافت توکن از API.');
    }

    $url = 'https://api.app.sobhan.net/' . $endpoint;

    $args = [
        'method' => $method,
        'headers' => [
            'Authorization' => 'Token ' . $token,
            'Content-Type' => 'application/json',
        ],
    ];

    if ($body) {
        $args['body'] = json_encode($body);
    }

    $response = wp_remote_request($url, $args);

    if (is_wp_error($response)) {
        return new WP_Error('api_error', 'خطا در درخواست API: ' . $response->get_error_message());
    }

    $response_body = wp_remote_retrieve_body($response);
    $response_code = wp_remote_retrieve_response_code($response);

    if ($response_code !== 200) {
        return new WP_Error('api_error', 'خطا در API با کد وضعیت ' . $response_code . ': ' . $response_body);
    }

    return json_decode($response_body, true);
}


?>
