<?php
include_once(plugin_dir_path(__FILE__) . 'jdf.php');

// Create invoice on order
add_action('woocommerce_order_status_completed', 'accounting_api_create_invoice');
function accounting_api_create_invoice($order_id) {
    $order = wc_get_order($order_id);
    $items = array();
    foreach ($order->get_items() as $item) {
        $product = $item->get_product();
        $items[] = array(
            'sku' => $product->get_sku(),
            'quantity' => $item->get_quantity(),
            'price' => $item->get_total(),
        );
    }

    $body = array(
        'order_id' => $order->get_id(),
        'customer' => array(
            'name' => $order->get_billing_first_name() . ' ' . $order->get_billing_last_name(),
            'email' => $order->get_billing_email(),
        ),
        'items' => $items,
    );

    accounting_api_connector_request('invoices', 'POST', $body);
}

// Add invoice icon in WooCommerce orders
// add_filter('woocommerce_admin_order_actions', 'add_invoice_icon_to_orders', 10, 2);
// function add_invoice_icon_to_orders($actions, $order) {
//     $actions['generate_invoice'] = array(
//         'url' => admin_url('admin-ajax.php?action=generate_invoice&order_id=' . $order->get_id()),
//         'name' => __('View Invoice', 'woocommerce'),
//         'action' => 'view invoice'
//     );
//     return $actions;
// }
add_action('woocommerce_admin_order_actions_end', 'add_invoice_icon_to_orders', 10, 1);
function add_invoice_icon_to_orders($order) {
    // Ensure the passed parameter is an order object
    if (!is_a($order, 'WC_Order')) {
        return;
    }

    // Get the order ID from the order object
    $order_id = $order->get_id();

    // Set the correct URL for the image. Adjust the path as needed.
    $image_url = plugin_dir_url(__FILE__) . '../assets/images/invoice.png'; // Correct relative path for the plugin directory

    // Ensure the action URL is generated correctly.
    $action_url = admin_url('admin-ajax.php?action=generate_invoice&order_id=' . $order_id);

    // HTML for the custom button with image.
    echo '<a href="' . esc_url($action_url) . '" class="button wc-action-button" target="_blank" aria-label="' . esc_attr__('View Invoice', 'woocommerce') . '">
            <img src="' . esc_url($image_url) . '" alt="' . esc_attr__('View Invoice', 'woocommerce') . '" style="width:16px; height:auto; margin-right: 5px; vertical-align:middle;" />
          </a>';
}



// Generate invoice
add_action('wp_ajax_generate_invoice', 'generate_invoice');
add_action('wp_ajax_nopriv_generate_invoice', 'generate_invoice');
function generate_invoice() {
    if (!isset($_GET['order_id'])) {
        wp_die('Invalid order ID');
    }
    
    $order_id = intval($_GET['order_id']);
    $order = wc_get_order($order_id);
    if (!$order) {
        wp_die('Order not found');
    }
    
    $logo = get_option('accounting_api_logo');
    if (!$logo) {
        $logo = ''; // Provide a default logo URL or leave it empty
    }

    // Retrieve order data
    $seller_name = get_option('seller_name');
    $seller_economic_number = get_option('seller_economic_number');
    $seller_registration_number = get_option('seller_registration_number');
    $seller_address = get_option('seller_address');
    $seller_postcode = get_option('seller_postcode');
    $seller_phone = get_option('seller_phone');
    $created_date = $order->get_date_created();
	$formatted_date = jdate('Y/m/d', strtotime($created_date));
	$payment_method = $order->get_payment_method_title();
	$shipping_total = $order->get_shipping_total();
    $customer_name = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
    $customer_address = $order->get_billing_address_1() . ' ' . $order->get_billing_city() . ' ' . $order->get_billing_postcode();
    $customer_phone = $order->get_billing_phone();
    
    $items = $order->get_items();
    $items_html = '';
    $item_counter = 1;
    foreach ($items as $item) {
        $product = $item->get_product();
        if ($product) {
            $regular_price = $product->get_regular_price();
            $sale_price = $product->get_sale_price();
            $discount = $regular_price - $sale_price;
    
            $product_name = $product->get_name();
            $product_sku = $product->get_sku();
            $product_quantity = $item->get_quantity();
            $product_unit = 'عدد'; // فرض اینکه واحد اندازه‌گیری عدد است
            $product_price = $item->get_total();
            $product_total_after_discount = $sale_price * $product_quantity;
            $product_tax = $item->get_total_tax(); // جمع مالیات و عوارض
            $product_final_total = $product_total_after_discount + $product_tax;
    
            $items_html .= '<tr class="text-center">
                                <td>' . $item_counter . '</td>
                                <td>' . esc_html($product_sku) . '</td>
                                <td>' . esc_html($product_name) . '</td>
                                <td>' . esc_html($product_quantity) . '</td>
                                <td>' . esc_html($product_unit) . '</td>
                                <td>' . esc_html(number_format($regular_price, 0)) . '</td>
                                <td>' . esc_html(number_format($regular_price * $product_quantity, 0)) . '</td>
                                <td>' . esc_html(number_format($discount * $product_quantity, 0)) . '</td>
                                <td>' . esc_html(number_format($product_total_after_discount, 0)) . '</td>
                                <td>' . esc_html(number_format($product_tax, 0)) . '</td>
                                <td>' . esc_html(number_format($product_final_total, 0)) . '</td>
                            </tr>';
            $item_counter++;
        }
    }
    
    

    // Output invoice HTML
    echo '<html><head>
            <meta name="viewport" content="width=device-width, initial-scale=1" />
            <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.5.3/dist/css/bootstrap.min.css" integrity="sha384-TX8t27EcRE3e/ihU7zmQxVncDAy5uIKz4rEkgIXeMed4M0jlfIDPvg6uqKI2xXr2" crossorigin="anonymous" />
            <link rel= "stylesheet" href="'. plugin_dir_url(__FILE__) .'../assets/css/style.css" media="all" />
            <title>فاکتور فروش</title>
        </head>
        <body dir="rtl">
        <style>
    @media print {
        #printButton {
            display: none;
        }
    }
</style>

            <div class="container-xl" style="margin-top: 100px;">
                <div class="row">
                    <div class="col-3 text-center">
                        <center><img src="' . esc_url($logo) . '" width="80px" height="90px"></center>
                    </div>
                    <div class="col-6 text-center">
                        <h3 class="font-weight-bold">صورتحساب فروش کالا و خدمات</h3>
                    </div>
                    <div class="col-3 text-right">
                        <p>شماره سفارش: ' . $order->get_order_number() . '</p>
                        <p>تاریخ سفارش: ' . esc_html($formatted_date) . '</p>
                        
                        </div>
						<button id="printButton" onclick="printInvoice()">پرینت</button>
                </div>
                <div class="row">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th class="text-center" colspan="11">مشخصات فروشنده</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td colspan="11" class="text-right">
                                    <div class="row">
                                        <div class="col-4">
                                            <p>نام شخص حقیقی / حقوقی: ' . esc_html($seller_name) . '</p>
                                            <p>آدرس کامل: ' . esc_html($seller_address) . '</p>
                                        </div>
                                        <div class="col-4">
                                            <p>شماره اقتصادی: ' . esc_html($seller_economic_number) . '</p>
                                            <p>کد پستی: ' . esc_html($seller_postcode) . '</p>
                                        </div>
                                        <div class="col-4">
                                            <p>شماره ثبت / شناسه ملی: ' . esc_html($seller_registration_number) . '</p>
                                            <p>تلفن / نمابر: ' . esc_html($seller_phone) . '</p>
                                        </div>
                                    </div>
                                </td>
                            </tr>
                        </tbody>
                        <thead>
                            <tr>
                                <th class="text-center" colspan="11">مشخصات خریدار</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td colspan="11" class="text-right">
                                    <div class="row">
                                        <div class="col-4">
                                            <p>نام شخص حقیقی / حقوقی: ' . esc_html($customer_name) . '</p>
                                            <p>آدرس کامل: ' . esc_html($customer_address) . '</p>
                                        </div>
                                        <div class="col-4">
                                            <p>شماره اقتصادی:</p>
                                            <p>کد پستی:</p>
                                        </div>
                                        <div class="col-4">
                                            <p>شماره ثبت / شناسه ملی:</p>
                                            <p>تلفن / نمابر: ' . esc_html($customer_phone) . '</p>
                                        </div>
                                    </div>
                                </td>
                            </tr>
                        </tbody>
                        <thead>
                            <tr>
                                <th class="text-center" colspan="11">مشخصات کالا یا خدمات مورد معامله</th>
                            </tr>
                        </thead>
                        <thead>
                            <tr class="text-center">
                            <th>ردیف</th>
                            <th>کد کالا</th>
                            <th>شرح کالا یا خدمات</th>
                            <th>تعداد / مقدار</th>
                            <th>واحد اندازه‌گیری</th>
                            <th>مبلغ واحد (ریال)</th>
                            <th>مبلغ کل (ریال)</th>
                            <th>مبلغ تخفیف (ریال)</th>
                            <th>مبلغ کل پس از تخفیف (ریال)</th>
                            <th>جمع مالیات و عوارض (ریال)</th>
                            <th>جمع مبلغ کل به علاوه مالیات و عوارض (ریال)</th>
                        </tr>
                    </thead>
                    <tbody>
';

$item_counter = 1;
$total_price = 0;
$total_discount = 0;
$total_tax = 0;

foreach ($items as $item) {
    $product = $item->get_product();
    if ($product) {
        $regular_price = $product->get_regular_price();
        $sale_price = $product->get_sale_price();
        $discount = $regular_price - $sale_price;

        $quantity = $item->get_quantity();
        $total = $regular_price * $quantity;
        $price_after_discount = $sale_price * $quantity;
        $tax = $item->get_total_tax();
        $final_total = $price_after_discount + $tax;

        $total_price += $total;
        $total_discount += ($discount * $quantity);
        $total_tax += $tax;

        echo "
            <tr class='text-center'>
                <td>{$item_counter}</td>
                <td>" . esc_html($product->get_sku()) . "</td>
                <td>" . esc_html($product->get_name()) . "</td>
                <td>" . esc_html($quantity) . "</td>
                <td>عدد</td>
                <td>" . esc_html(number_format($regular_price, 0, ',', ',')) . "</td>
                <td>" . esc_html(number_format($total, 0, ',', ',')) . "</td>
                <td>" . esc_html(number_format($discount * $quantity, 0, ',', ',')) . "</td>
                <td>" . esc_html(number_format($price_after_discount, 0, ',', ',')) . "</td>
                <td>" . esc_html(number_format($tax, 0, ',', ',')) . "</td>
                <td>" . esc_html(number_format($final_total, 0, ',', ',')) . "</td>
            </tr>
        ";

        $item_counter++;
    }
}
$grand_total = $total_price - $total_discount + $total_tax + $shipping_total;
echo "
    <tr>
        <th colspan='5' class='text-right'>جمع کل</th>
        <th class='text-center'>" . esc_html(number_format($total_price, 0, ',', ',')) . "</th>
        <th class='text-center'>" . esc_html(number_format($total_price, 0, ',', ',')) . "</th>
        <th class='text-center'>" . esc_html(number_format($total_discount, 0, ',', ',')) . "</th>
        <th class='text-center'>" . esc_html(number_format($total_price - $total_discount, 0, ',', ',')) . "</th>
        <th class='text-center'>" . esc_html(number_format($total_tax, 0, ',', ',')) . "</th>
        <th class='text-center'>" . esc_html(number_format($total_price - $total_discount + $total_tax, 0, ',', ',')) . "</th>
    </tr>
    <tr>
    <th colspan='5' class='text-right'> هزینه پست</th>
        <th colspan='6' class='text-center'>" . esc_html(number_format($shipping_total, 0, ',', ',')) . "</th>
    </tr>
    <th colspan='5' class='text-right'> مبلغ قابل پرداخت</th>
        <th colspan='6' class='text-center'>" . esc_html(number_format($grand_total, 0, ',', ',')) . "</th>
    </tr>
    <th colspan='5' class='text-right'> شرایط پرداخت: " . esc_html($payment_method) . "</th>
        <th colspan='6' class='text-right'>توضیحات:</th>
    </tr>
    <tr style='padding: 60px 0;'>
        <td colspan='5' class='text-right'>مهر و امضا فروشنده</td>
        <td colspan='6' class='text-right'>مهر و امضا خریدار</td>
    </tr>
</tbody>
</table>
</div>
</div>
<script>
    function printInvoice() {
        window.print();
    }
</script>
</body>
</html>";

exit;

}
?>

