<?php
// Create shipping label on order
add_action('woocommerce_order_status_completed', 'accounting_api_create_shipping_label');
function accounting_api_create_shipping_label($order_id) {
    $order = wc_get_order($order_id);
    $items = array();
    foreach ($order->get_items() as $item) {
        $product = $item->get_product();
        $items[] = array(
            'sku' => $product->get_sku(),
            'quantity' => $item->get_quantity(),
            'price' => $item->get_total(),
        );
    }

    $body = array(
        'order_id' => $order->get_id(),
        'customer' => array(
            'name' => $order->get_billing_first_name() . ' ' . $order->get_billing_last_name(),
            'email' => $order->get_billing_email(),
        ),
        'items' => $items,
        'shipping_address' => array(
            'address_1' => $order->get_shipping_address_1(),
            'address_2' => $order->get_shipping_address_2(),
            'city' => $order->get_shipping_city(),
            'state' => $order->get_shipping_state(),
            'postcode' => $order->get_shipping_postcode(),
            'country' => $order->get_shipping_country(),
        ),
    );

    accounting_api_connector_request('shipping-labels', 'POST', $body);
}
// Add a custom action button with image in WooCommerce orders
add_action('woocommerce_admin_order_actions_end', 'add_shipping_label_image_button', 10, 1);
function add_shipping_label_image_button($order) {
    // Ensure the passed parameter is an order object
    if (!is_a($order, 'WC_Order')) {
        return;
    }

    // Get the order ID from the order object
    $order_id = $order->get_id();

    // Set the correct URL for the image. Adjust the path as needed.
    $image_url = plugin_dir_url(__FILE__) . '../assets/images/post.png'; // Correct relative path for the plugin directory

    // Ensure the action URL is generated correctly.
    $action_url = admin_url('admin-ajax.php?action=generate_shipping_label&order_id=' . $order_id);

    // HTML for the custom button with image.
    echo '<a href="' . esc_url($action_url) . '" class="button wc-action-button" target="_blank" aria-label="' . esc_attr__('Generate Shipping Label', 'woocommerce') . '">
            <img src="' . esc_url($image_url) . '" alt="' . esc_attr__('Generate Shipping Label', 'woocommerce') . '" style="width:16px; height:auto; margin-right: 5px; vertical-align:middle;" />
          </a>';
}

// Generate shipping label
add_action('wp_ajax_generate_shipping_label', 'generate_shipping_label');
add_action('wp_ajax_nopriv_generate_shipping_label', 'generate_shipping_label');
function generate_shipping_label() {
    if (!isset($_GET['order_id'])) {
        wp_die('Invalid order ID');
    }
    
    $order_id = intval($_GET['order_id']);
    $order = wc_get_order($order_id);
    if (!$order) {
        wp_die('Order not found');
    }

    // Retrieve order data
    $order_number = $order->get_order_number();
    $name = $order->get_shipping_first_name() . ' ' . $order->get_shipping_last_name();
    $address = $order->get_shipping_address_1() . ' ' . $order->get_shipping_address_2() . ' ' . $order->get_shipping_city() . ' ' . $order->get_shipping_postcode();
    $country = $order->get_shipping_country();
    $state = $order->get_shipping_state();
	$created_date = $order->get_date_created();
	$formatted_date = jdate('Y/m/d', strtotime($created_date));

    // Retrieve sender data from settings
    $sender_name = get_option('shipping_sender_name');
    $sender_address = get_option('shipping_sender_address');
    $sender_postcode = get_option('shipping_sender_postcode');
    $sender_phone = get_option('shipping_sender_phone');


    $items = $order->get_items();
    $items_html = '';
    foreach ($items as $item) {
        $product = $item->get_product();
        if ($product) {
            $product_name = $product->get_name();
        } else {
            $product_name = __('Product not found', 'woocommerce');
        }
        $items_html .= '<tr><td>' . esc_html($product_name) . '</td><td>' . esc_html($item->get_quantity()) . '</td><td>' . esc_html($item->get_total()) . '</td></tr>';
    }

    // Output shipping label HTML with the provided template
    echo '
    <html>
    <head>
        <meta name="viewport" content="width=device-width, initial-scale=1" />
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.5.3/dist/css/bootstrap.min.css" integrity="sha384-TX8t27EcRE3e/ihU7zmQxVncDAy5uIKz4rEkgIXeMed4M0jlfIDPvg6uqKI2xXr2" crossorigin="anonymous" />
		<link rel= "stylesheet" href="'. plugin_dir_url(__FILE__) .'../assets/css/style.css" media="all" />
        <title>برچسب پست</title>
    </head>
    <body dir="rtl">
	 <style>
    @media print {
        #printButton {
            display: none;
        }
    }
</style>
        <div class="container-xl" style="margin-top: 100px;">
            <div class="row">
                <div class="col-3 text-center"></div>
                <div class="col-6 text-center"><h3 class="font-weight-bold">مشخصات پستی کالا</h3></div>
                <div class="col-3 text-right">
                    <p>شماره سفارش: ' . esc_html($order_number) . '</p>
                    <p>تاریخ سفارش: '. esc_html($formatted_date) . '</p>
                </div>
				<button id="printButton" onclick="printInvoice()">پرینت</button>
            </div>
            <div class="row">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th class="text-center" colspan="11">مشخصات فرستنده</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td colspan="11" class="text-right">
                                <div class="row">
                                    <div class="col-2">
                                        <center> <img src="'.plugin_dir_url(__FILE__) .'../assets/images/logopost.png" width="80px" height="90px"></center>
                                    </div>
                                    <div class="col-5">
                                        <p>نام شخص حقیقی / حقوقی: ' . esc_html($sender_name) . '</p>
                                    </div>
                                    <div class="col-5">
                                        <p>شماره همراه: ' . esc_html($sender_phone) . '</p>
                                        <p>کد پستی: ' . esc_html($sender_postcode) . '</p>
                                    </div>
                                    <div class="col-10">
                                        <p>آدرس کامل: ' . esc_html($sender_address) . '</p>
                                    </div>
                                </div>
                            </td>
                        </tr>
                    </tbody>
                    <thead>
                        <tr>
                            <th class="text-center" colspan="11">مشخصات گیرنده</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td colspan="11" class="text-right">
                                <div class="row">
                                    <div class="col-2">
                                        <center> <img src="'.plugin_dir_url(__FILE__) .'../assets/images/logopost.png" width="80px" height="90px"></center>
                                    </div>
                                    <div class="col-5">
                                        <p>نام شخص حقیقی / حقوقی: ' . esc_html($name) . '</p>
                                    </div>
                                    <div class="col-5">
                                        <p>شماره همراه: ' . esc_html($order->get_billing_phone()) . '</p>
                                        <p>کد پستی: ' . esc_html($order->get_shipping_postcode()) . '</p>
                                    </div>
                                    <div class="col-10">
                                        <p>آدرس کامل: ' . esc_html($address) . '</p>
                                    </div>
                                </div>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
		<script>
    function printInvoice() {
        window.print();
    }
</script>
    </body>
    </html>';

    exit;
}
?>
