<?php
function accounting_api_update_stock($idanbar) {
    // دریافت توکن از API
    $token = get_option('accounting_api_token');

    // درخواست توکن جدید در صورت عدم وجود یا منقضی شدن توکن
    if (!$token) {
        echo '<div class="error"><p>توکن معتبر یافت نشد. لطفاً دوباره تلاش کنید.</p></div>';
        error_log('Token not found or invalid.');
        $token = accounting_api_get_token();
        if (!$token) {
            echo '<div class="error"><p>خطا در دریافت توکن جدید.</p></div>';
            return;
        }
    }

    // ارسال درخواست به API برای دریافت لیست محصولات
    $url = 'https://api.app.sobhan.net/store/inventory?warehouse=' . $idanbar;
    $response = wp_remote_get($url, array(
        'headers' => array(
            'Authorization' => 'Token ' . $token, // اضافه کردن API Key به هدر
            'Content-Type'  => 'application/json',
        ),
    ));

    // بررسی خطا در درخواست API
    if (is_wp_error($response)) {
        $error_message = $response->get_error_message();
        error_log('Error in API request: ' . $error_message);
        echo '<div class="error"><p>خطا در ارسال درخواست به سرور: ' . $error_message . '</p></div>';
        return;
    }

    // پردازش پاسخ API
    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    // بررسی وجود پیام خطای توکن نامعتبر
    if (isset($data[0]['messages'][0]) && strpos($data[0]['messages'][0], 'توکن هدر نامعتبر') !== false) {
        error_log('Invalid token detected. Fetching a new token.');

        // دریافت توکن جدید
        $token = accounting_api_get_token();
        if (!$token) {
            echo '<div class="error"><p>خطا در دریافت توکن جدید.</p></div>';
            return;
        }

        // ارسال دوباره درخواست با توکن جدید
        $response = wp_remote_get($url, array(
            'headers' => array(
                'Authorization' => 'Token ' . $token,
                'Content-Type'  => 'application/json',
            ),
        ));

        // بررسی خطای درخواست دوم
        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            error_log('Error in second API request: ' . $error_message);
            echo '<div class="error"><p>خطا در ارسال درخواست به سرور: ' . $error_message . '</p></div>';
            return;
        }

        // پردازش پاسخ جدید
        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);
    }

    // بررسی داده‌های دریافتی و بروزرسانی محصولات
    if (is_array($data)) {
        $updated_products = 0;

        foreach ($data as $product_data) {
            $sku = $product_data['ware'] ?? null;
            $quantity = $product_data['count'] ?? null;

            if ($sku && $quantity !== null) {
                // جستجوی محصول و به‌روزرسانی موجودی
                $product_id = wc_get_product_id_by_sku($sku);
                if ($product_id) {
                    $product = wc_get_product($product_id);
                    $product->set_stock_quantity($quantity);
                    $product->save();
                    $updated_products++;
                }
            }
        }

        // نمایش تعداد محصولات به روز رسانی شده
        if ($updated_products > 0) {
            echo '<div class="updated"><p>' . $updated_products . ' محصول به‌روزرسانی شد.</p></div>';
        } else {
            echo '<div class="error"><p>هیچ محصولی برای به‌روزرسانی یافت نشد.</p></div>';
        }
    } else {
        error_log('Invalid response data: ' . $body);
        echo '<div class="error"><p>خطا در دریافت داده‌ها از سرور.</p></div>';
    }
}


?>
